summaryrefslogtreecommitdiffstats
path: root/src/gui/studio/MidiProgramsEditor.h
diff options
context:
space:
mode:
authorSlávek Banko <[email protected]>2013-02-19 04:51:33 +0100
committerSlávek Banko <[email protected]>2013-02-19 04:51:33 +0100
commite046563944f8ea6089149363908cd2249c1b29f4 (patch)
treed57cef926dfa671923cafc08dac52493047e729f /src/gui/studio/MidiProgramsEditor.h
parent4f3d7ccfbb037354bcc47a0cfd02cf3cc5d48780 (diff)
downloadrosegarden-e046563944f8ea6089149363908cd2249c1b29f4.tar.gz
rosegarden-e046563944f8ea6089149363908cd2249c1b29f4.zip
Fix unintended rename of many various *klist*
Diffstat (limited to 'src/gui/studio/MidiProgramsEditor.h')
-rw-r--r--src/gui/studio/MidiProgramsEditor.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/gui/studio/MidiProgramsEditor.h b/src/gui/studio/MidiProgramsEditor.h
index f583ec3..7d40e8e 100644
--- a/src/gui/studio/MidiProgramsEditor.h
+++ b/src/gui/studio/MidiProgramsEditor.h
@@ -78,9 +78,9 @@ protected:
int ensureUniqueMSB(int msb, bool ascending);
int ensureUniqueLSB(int lsb, bool ascending);
// Does the bantdelist contain this combination already?
//
- bool bantdelistContains(const MidiBank &);
+ bool banklistContains(const MidiBank &);
ProgramList getBankSubset(const MidiBank &);
@@ -78,9 +78,9 @@ protected:
int ensureUniqueMSB(int msb, bool ascending);
int ensureUniqueLSB(int lsb, bool ascending);
- // Does the bantdelist contain this combination already?
+ // Does the banklist contain this combination already?
//